% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/as-distance.R
\name{as.distance}
\alias{as.distance}
\title{Convert correlations to distances.}
\usage{
as.distance(network, type = "positive", range = "unit")
}
\arguments{
\item{network}{A numerical matrix (as returned for example by
\code{cor}) of correlations between nodes/vertices of a network.}

\item{type}{One of 'positive' (only positive edges are retained; the default)
, 'absolute' (absolute values are retained, so that a negative-weighted edge
will have the same distance as if it were positive) or 'scaled' (where
negative-weighted edges have greater distances and uncorrelated edges will
have intermediate distances).}

\item{range}{One of 'unit' (edge weights are in the range -1 to 1 as for a
correlation matrix; the default) or 'range' (the edge weights will be scaled
so that the range of supplied weights ends up on the scale 0 to 1).}
}
\value{
A matrix, of the same dimensions (and row/column names) as the input,
containing the edge weights as distances. Thus, the most highly-correlated
edges will tend to 0 and uncorrelated edges will tend to 1.
}
\description{
Convert a correlation matrix (or other adjacency matrix)
into a distance matrix.
}
\examples{
\dontrun{
require(DataNet)
# Load example data and create distance matrix
data(hipExpr)
network = cor(hipExpr, method="pearson", use="pairwise.complete.obs")
distance.matrix = as.distance(network)
}

}
