% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/as-edge-list.R
\name{as.edge.list}
\alias{as.edge.list}
\title{Convert a distance matrix to an edge list.}
\usage{
as.edge.list(network, threshold)
}
\arguments{
\item{network}{A numerical matrix (as returned for example by
\code{\link{as.distance}}) of distances between nodes/vertices of a network.
Values must be positive and will usually lie in the range 0--1 (although
no upper bound is set).}

\item{threshold}{A threshold above which edges will not be included in the
edge list.}
}
\value{
A \code{data.frame} representing the edges of a network. The columns
\code{source} and \code{target} are character vectors containing the IDs of the
source and target nodes respectively (the column and row names of the
correponding elements of the distance matrix). The column \code{distance} is
a numeric vector containing the value of the of the correponding element of
the distance matrix.
}
\description{
Convert a distance matrix representing an undirected
network into an edge list.
}
\details{
This function efficiently transforms the lower triangle of a distance matrix
into a \code{data.frame} representing the edges of a network.
}
\examples{
\dontrun{
require(DataNet)
# Load example data and create distance matrix
data(hipExpr)
network = cor(hipExpr, method="pearson", use="pairwise.complete.obs")
distance.matrix = as.distance(network)

# Convert to edge list
edge.list = as.edge.list(distance.matrix, 0.4)
}

}
