% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/draw-stick-graph.R
\name{draw.stick.graph}
\alias{draw.stick.graph}
\title{Plot a network as a graph of edges coloured by weight.}
\usage{
draw.stick.graph(edge.list, coordinates, plot.edges = 1:nrow(edge.list),
  plot.vertices = 1:nrow(coordinates),
  edge.colours = colorRampPalette(c("red", "yellow", "white"))(256),
  new = TRUE, return.coordinates = FALSE, ...)
}
\arguments{
\item{edge.list}{A \code{data.frame} with two \code{character} columns,
'source' and 'target', containing the vertex IDs, and one \code{numeric}
column, distance, containing the optimal edge distance.}

\item{coordinates}{A \code{data.frame} with two \code{numeric} columns,
\code{x} and \code{y} containing the Cartesian coordinates of the vertices.
The vertex IDs (provided as the row names of this \code{data.frame}) must
correspond to the vertices used in the edge list. This object can be
generated using the function \code{\link{fast.force.layout}}.}

\item{plot.edges}{A vector, the same length as the number of rows of
\code{edge.list}, specifying which edges are to be drawn (default is all
edges). The vector may be logical, numeric or character if the edge.list has
rownames).}

\item{plot.vertices}{A vector, the same length as the number of rows of
\code{edge.list}, specifying which vertices (nodes) are to be drawn (default
is all vertices). The vector may be logical, numeric or character (
corresponding to the rownames of \code{coordinates}).}

\item{edge.colours}{A vector of colours which will be used as a colour scale
from the closest to most distant edges. Colours can be specified in any of
the three R formats.}

\item{new}{Logical ( \code{TRUE} by default). Whether to create a new plot.
If \code{FALSE}, the graph will be drawn over the existing plot (enabling
additional plotting layers to be added).}

\item{return.coordinates}{Logical ( \code{FALSE} by default). Whether to
create a new plot. If \code{TRUE}, the graph will be drawn over the existing
plot (enabling additional plotting layers to be added).}

\item{...}{Addtional arguments to be passed to \code{\link[graphics]{segments}}.}
}
\value{
If \code{return.coordinates} is \code{TRUE}, then a \code{data.frame}
will be returned containing the same information as the \code{edge.list} but
with additional columns describing the Cartesian coordinates of the source
and target vertices as well as the colour in which the edge was plotted. The
default (\code{return.coordinates} = FALSE) returns nothing.
}
\description{
Plot a network as a graph of edges (vertices are not drawn) coloured by
the weight/optimal distance.
}
\details{
This function provides a convenient way to plot results of
\code{\link{fast.force.layout}}. The edge list, which can be derived from a
distance matrix using \code{\link{as.edge.list}}, is the same as provided to
\code{\link{fast.force.layout}} which returns the 'coordinates' object also
required for this function.
}
\examples{
\dontrun{
require(DataNet)
# Load example data and create distance matrix
data(hipExpr)
network = cor(hipExpr, method="pearson", use="pairwise.complete.obs")
distance.matrix = as.distance(network)

# Convert to edge list
edge.list = as.edge.list(distance.matrix, 0.4)

# Calculate coordinates
coordinates = fast.force.layout(edge.list)

# Plot graph
draw.stick.graph(edge.list, coordinates)

}

}
