% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fast-force-layout.R
\name{fast.force.layout}
\alias{fast.force.layout}
\title{Force-directed graph layout.}
\usage{
fast.force.layout(edge.list, extend = NULL, iterations = 1, k = 0.5,
  repelling.edges = 1)
}
\arguments{
\item{edge.list}{A \code{data.frame} representing the edges of a network. The
columns \code{source} and \code{target} are character vectors containing the
IDs of the source and target nodes respectively. The column \code{distance}
is a numeric vector containing the value of the of the correponding element
of the distance matrix.}

\item{extend}{A \code{data.frame} of vertex coordinates, as returned by this
function. If supplied, then these coordinates will be used as starting
postions. The default value of NULL will place all vertices at the origin.
It is important that the random seed is set to be the same for all
iterations if a reproducible layout is required. This can be done by calling
\code{\link[base]{set.seed}} before performing the layout.}

\item{iterations}{An integer specifying the number of iterations to be
performed. In each iteration, the length of every edge is compared against
the desired distance and the position of the associated vertices adjusted
accordingly.}

\item{k}{A \code{double} specifying the fraction of the displacement (the
difference between the desired and actual edge lengths) by which each edge
length is altered in each itereation. The default value is 0.5 (half the
displacement).}

\item{repelling.edges}{The fraction of edges which are randomly selected in
each iteration for calculation of repulsion. Optimally, this value is set at
1 (all edges; default) but for large networks this significantly affects
performance. A value of 0.01 (10 % of edges), for example, yields fast
computation times while retaining a reasonable layout.}
}
\value{
A \code{data.frame} of vertex coordinates with columns x and y. The
vertex IDs are provided as row names.
}
\description{
Plotting function for network vertices laid out on
a grid.
}
\examples{
\dontrun{
require(DataNet)
# Load example data and create distance matrix
data(hipExpr)
network = cor(hipExpr, method = "pearson", use = "pairwise.complete.obs")
distance.matrix = as.distance(network)

# Convert to edge list
edge.list = as.edge.list(distance.matrix, 0.4)

# Calculate coordinates
coordinates = fast.force.layout(edge.list, iterations = 100)

# Plot graph
draw.stick.graph(edge.list, coordinates)

}

}
